@@ -80,7 +80,7 @@ try {
     print "Opened non-existent stub database\n";
     exit(1);
 } catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseOpeningError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
+    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
 	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
 	exit(1);
     }
@@ -92,8 +92,8 @@ try {
     print "Opened non-existent stub database\n";
     exit(1);
 } catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseOpeningError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
-	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
+    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
+	print "DatabaseNotFoundError Exception string not as expected, got: '{$e->getMessage()}'\n";
 	exit(1);
     }
 }
@@ -104,7 +104,7 @@ try {
     print "Opened non-existent stub database\n";
     exit(1);
 } catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseOpeningError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
+    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
 	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
 	exit(1);
     }
@@ -117,8 +117,8 @@ try {
     print "Opened non-existent stub database\n";
     exit(1);
 } catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseOpeningError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
-	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
+    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
+	print "DatabaseNotFoundError Exception string not as expected, got: '{$e->getMessage()}'\n";
 	exit(1);
     }
 }
@@ -200,6 +200,12 @@ if ($query3->get_description() != "Query((a OR b))") {
     exit(1);
 }
 $enq = new XapianEnquire($db);
+
+// This ought to be wrapped as a constant, but this tests how it has been
+// wrapped for some time in PHP bindings, which we need to maintain for
+// compatibility with existing user code.
+$enq->set_collapse_key(Xapian::BAD_VALUENO_get());
+
 $enq->set_query(new XapianQuery(XapianQuery::OP_OR, "there", "is"));
 $mset = $enq->get_mset(0, 10);
 if ($mset->size() != 1) {
